@@ -76,10 +76,10 @@ def update_cdf_keys(new_keys):
 
 
 def generate_default_project_settings(
-    yaml_file='mlops_settings.yaml', 
+    yaml_file=Path('mlops_settings.yaml'), 
     n_models=2
 ):
-    if os.path.isfile(yaml_file):
+    if yaml_file.exists():
         raise Exception(f"Settings file {yaml_file} exists already.")
     
     default_config = [ 
@@ -156,7 +156,7 @@ class ServiceSettings():
 
         self.files = {
             "model code": helpers.get_top_folder(self.model_file), 
-            "handler": (f"akerbp.mlops.cdf","handler.py"),
+            "handler": ("akerbp.mlops.cdf", "handler.py"),
             "artifact folder": self.artifact_folder
         }
         if self.platform == "gc":
