@@ -6,60 +6,60 @@ Model registry uses CDF Files.
 """ 
 import os
 import traceback
-import shutil
+from pathlib import Path
 
 import akerbp.mlops.model_manager as mm
 from akerbp.mlops.deployment import helpers, platforms
 from akerbp.mlops.core import logger, config
 logging=logger.get_logger(name='mlops_deployment')
-env = config.envs.env
-service_name = config.envs.service_name
+
 
 platform_methods = platforms.get_methods()
 
-def deploy_model(model_settings, platform_methods=platform_methods):
 
+def deploy_model(model_settings, platform_methods=platform_methods):
+    """
+    Deploy a model.
+
+    This will create a deployment folder and change cwd to it.
+
+    Input:
+        - model_settings: (ServiceSettings) settings for the model service
+        - platform_methods: (dictionary) where key is the platform and value
+            is a tuple with deploy and test functions.
+    """
     c = model_settings
+    env = config.envs.env
+    service_name = config.envs.service_name
+    deployment_folder = helpers.deployment_folder_path(c.model_name)
+    function_name = f"{c.model_name}-{service_name}-{env}"
+
     logging.debug(" ")
     logging.info(f"Deploy model {c.model_name}")
 
-    deployment_folder =f'mlops_{c.model_name}'
-    function_name=f"{c.model_name}-{service_name}-{env}"
-
     if service_name == 'prediction':
-        c.model_id = mm.set_up_model_artifact(
-            c.artifact_folder, 
-            c.model_name
-        )
+        c.model_id = mm.set_up_model_artifact(c.artifact_folder, c.model_name)
 
-    m = "Create deployment folder and move required files/folders"
-    logging.info(m)
-    os.mkdir(deployment_folder)
-    
+    logging.info("Create deployment folder and move required files/folders")
+    deployment_folder.mkdir()
     helpers.copy_to_deployment_folder(c.files, deployment_folder)
 
     logging.debug(f"cd {deployment_folder}")
     os.chdir(deployment_folder)
-    
     helpers.set_up_requirements(c)
-
     config.store_service_settings(c)
-
-    # * Dependencies: (user settings <- model test). Either run before
-    #   going to the dep. folder or copy project config to dep. folder. 
     # * It is important to run tests after setting up the artifact
     #   folder in case it's used to test prediction service.
     # * Tests need the model requirements installed!
     logging.info(f"Run model and service tests")
-    input, check = helpers.get_model_test_data(c.test_import_path)
     if c.test_file:
+        input, check = helpers.get_model_test_data(c.test_import_path)
         helpers.run_tests(c.test_file)
         from akerbp.mlops.services.test_service import test_service
         test_service(input, check)
     else:
         logging.warning("Model test file is missing! Didn't run tests")
 
-
     logging.info(f"Deploy {function_name} to {c.platform}")
     deploy_function, test_function = platform_methods[c.platform]
     deploy_function(function_name, info=c.info[service_name])
@@ -72,35 +72,39 @@ def deploy_model(model_settings, platform_methods=platform_methods):
 
 
 def deploy(project_settings):
+    """
+    Deploy a machine learning project that potentially contains multiple models.
+    Deploy each model in the settings and make sure that if one model fails it
+    does not affect the rest. At the end, if any model failed, it raises an
+    exception with a summary of all models that failed.
+
+    Input:
+        - Project settings as described by the user
+    """
     failed_models = {}
-    base_path = os.getcwd()
+    cwd_path = Path.cwd()
         
     for c in project_settings:
-        model_name = c.model_name
-        deployment_folder =f'mlops_{model_name}'
         try:
             deploy_model(c)
         except Exception:
             trace = traceback.format_exc()
-            error_message = f"Model failed to deploy!\n{trace}"
-            logging.error(error_message)
-            
-            failed_models[model_name] = error_message
+            message = f"Model failed to deploy!\n{trace}"
+            logging.error(message)
+            failed_models[c.model_name] = message
         finally:
             logging.debug(f"cd ..")
-            os.chdir(base_path)
-            logging.debug(f"Delete deployment folder")
-            if os.path.isdir(deployment_folder):
-                shutil.rmtree(deployment_folder)
+            os.chdir(cwd_path)
+            helpers.rm_deployment_folder(c.model_name)
 
     if failed_models:
-        for model_name, error_message in failed_models.items():
+        for model, message in failed_models.items():
             logging.debug(" ")
-            logging.info(f"Model {model_name} failed: {error_message}")
+            logging.info(f"Model {model} failed: {message}")
         raise Exception("At least one model failed.")
 
 
 if __name__ == '__main__':
     mm.setup()
-    s = config.read_project_settings()
-    deploy(s)
\ No newline at end of file
+    settings = config.read_project_settings()
+    deploy(settings)
\ No newline at end of file
