@@ -17,18 +17,6 @@ env = config.envs.env
 service_name = config.envs.service_name
 
 
-def get_version():
-    tag = subprocess.check_output(
-        ['git', 'describe', '--tags', '--abbrev=0'],
-        encoding='UTF-8'
-    ).rstrip()
-    if env in ['dev', 'test']:
-        version = '0.' + tag
-    elif env == 'prod':
-        version = '1.' + tag
-    return version
-
-
 def get_repo_origin():
     origin = subprocess.check_output(
         ['git', 'remote', 'get-url', '--push', 'origin'],
@@ -41,12 +29,12 @@ def replace_string_file(s_old, s_new, file):
     """
     Replaces all occurrences of s_old with s_new in a file
     """
-    with open(file) as f:
+    with file.open() as f:
         s = f.read()
         if s_old not in s:
             logging.warning(f"Didn't find '{s_old}' in {file}")
 
-    with open(file, 'w') as f:
+    with file.open('w') as f:
         s = s.replace(s_old, s_new)
         f.write(s)
 
@@ -63,34 +51,36 @@ def to_folder(path, folder_path):
     Note that if target exists it will be overwritten.
     Input:
       - path: supported formats
-            - folder path (string): e,g, "my/folder" 
-            - file path (string): e.g. "my/file" (string)
-            - module file (tuple/list): e.g. ("my.module", "my_file") 
+            - file/folder path (Path): e,g, Path("my/folder")
+            - module file (tuple/list): e.g. ("my.module", "my_file"). Module path has to be a string, but file name can be a Path object. 
     """
-    if isinstance(path,(tuple,list)):
-        if importlib_resources.is_resource(*path):
-            with importlib_resources.path(*path) as file_path:
+    if isinstance(path, (tuple,list) ):
+        module_path, file = path
+        file = str(file)
+        if importlib_resources.is_resource(module_path, file):
+            with importlib_resources.path(module_path, file) as file_path:
                 shutil.copy(file_path, folder_path)
         else:
             raise ValueError(f"Didn't find {path[1]} in {path[0]}")
-    elif os.path.isdir(path):
-        shutil.copytree(
-            path, 
-            os.path.join(folder_path, path), 
-            dirs_exist_ok=True
-        )
-    elif os.path.isfile(path):
+    elif path.is_dir():
+        shutil.copytree(path, folder_path/path, dirs_exist_ok=True)
+    elif path.is_file():
         shutil.copy(path, folder_path)
     else:
         raise ValueError(f"{path} should be a file, folder or package resource")
 
 
-def copy_to_deployment_folder(files, deployment_folder):
+def copy_to_deployment_folder(list, deployment_folder):
     """
-    Copy a list of files to a deployment folder
-    List of files is given as a dictionary where the key is the nick name of the file (will be used for logging) and the value is the path.
+    Copy a list of files/folders to a deployment folder
+    
+    Input:
+        - list: (dictionary), key is the nick name of the file/folder (used for
+        logging) and the value is the path (see `to_folder` for supported
+        formats)
+        - deployment_folder: (Path) 
     """
-    for k,v in files.items():
+    for k,v in list.items():
         logging.debug(f"{k} => deployment folder")
         to_folder(v, deployment_folder)
 
@@ -98,6 +88,7 @@ def copy_to_deployment_folder(files, deployment_folder):
 def run_tests(test_path, path_type='file'):
     """
     Run tests with pytest
+    
     Input
       - test_path: path to tests with pytest (string or a list of strings) All
         should have the same format (see next parameter)
@@ -127,8 +118,8 @@ def install_requirements(req_file):
 def set_up_requirements(c):
     """
     Set up a "requirements.txt" file at the top of the deployment folder
-    (assumed to be the current directory) and install dependencies (unless in
-    dev)
+    (assumed to be the current directory), update config and install
+    dependencies (unless in dev)
     """
     logging.info("Create requirement file")
     set_mlops_import(c.req_file)
@@ -138,9 +129,19 @@ def set_up_requirements(c):
         install_requirements('requirements.txt')
 
 
-
 def get_model_test_data(test_import_path):
     service_test = import_module(test_import_path).ServiceTest()
     input = getattr(service_test, f"{service_name}_input")
     check = getattr(service_test, f"{service_name}_check")
-    return input, check
\ No newline at end of file
+    return input, check
+
+
+def deployment_folder_path(model):
+    return Path(f'mlops_{model}')
+
+
+def rm_deployment_folder(model):
+    logging.debug(f"Delete deployment folder")
+    deployment_folder = deployment_folder_path(model)
+    if deployment_folder.exists():
+        shutil.rmtree(deployment_folder)
\ No newline at end of file
