@@ -45,7 +45,7 @@ def upload_new_model_version(model_name, env, folder, metadata):
         uploaded=None # count any file
     )
     latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
-    version = latest_v + 1
+    version = int(latest_v) + 1 # int64 isn't json-serializable
     if "version" in metadata:
         logging.error(
             "Metadata should not contain a 'version' key. "
@@ -103,12 +103,12 @@ def download_model_version(model_name, env, folder, metadata={}):
     Input: 
         -model_name: name of the model 
         -env: name of the environment ('dev', 'test', 'prod')
-        -folder: path to folder where the content will be uploaded
+        -folder: (Path) path to folder where the content will be uploaded
         -metadata: query to the metadata (dictionary)
     """
     external_id = find_model_version(model_name, env, metadata)
-    if not os.path.isdir(folder):
-        os.makedirs(folder)
+    if not folder.exists():
+        folder.mkdir()
     cdf.download_folder(external_id, folder)
     logging.info(f"Downloaded model with {external_id=} to {folder}")
     return external_id
@@ -120,14 +120,16 @@ def set_up_model_artifact(artifact_folder, model_name):
     When the prediction service is deployed, we need the model artifacts. These
     are downloaded, unless there's already a folder (local development
     environment only)
+    
     Input:
-      - artifact_folder 
+      - artifact_folder (Path)
       - model_name
+    
     Output:
-      - model_id: either the model id provided by the model manager, a hardcoded
-        value (existing folder in dev) or None (training service)
+      - model_id: either the model id provided by the model manager or a
+        hardcoded value (existing folder in dev)
     """
-    if os.path.isdir(artifact_folder):
+    if artifact_folder.exists():
         if env=='dev':
             logging.info(f"Use model artifacts in {artifact_folder=}")
             model_id=f'{model_name}/dev/1'
@@ -135,7 +137,7 @@ def set_up_model_artifact(artifact_folder, model_name):
         else:
             message = f"Existing artifacts won't be used ({env=})"
             logging.warning(message)
+    
     logging.info("Download serialized model")
     model_id = download_model_version(model_name, env, artifact_folder)
-
     return model_id
\ No newline at end of file
